/* 
Mikroekonometria 
Zajęcia 1 - Podstawy Stata: wczytywanie danych / transformacje / tworzenie list / regresja
CC BY: Wiktor Budziński
*/

// Tekst wyświetlany na zielono to komentarze (zwróć uwagę na symbole, którymi są oznaczane: '/* ... */', '... // ... ', '* ...')

// Ctrl-d wykonuje zaznaczony wiersz, Ctrl-r wykonuje bez drukowania outputu na ekran


// ZADANIE 1. Wygenerujmy własne (losowe) dane i wykorzystajmy je w modelu regresji liniowej 

clear // wyrzuca wszystkie zmienne z pamięci
cls // czyści okno outputu; może nie działać w starych wersjach Staty

/* Składnia poleceń:
- ważne tylko kilka pierwszych znaków 
- case sensitive
- spacje, tabulacje, znaki nowej linii są pomijane
*/
set seed 10311563
set obs 10000 // ustaw liczbę obserwacji
generate x1 = runiform() // generate tworzy nową zmienną; runiform() generuje zmienne losowe ze standardowego rozkładu jednostajnego
generate eps = rnormal(0,2) // rnormal generuje zmienne losowe z rozkładu normalnego o średniej 0 i odchyleniu standardowym 2

histogram eps 

// ZADANIE
	// Wygeneruj zmienna y jako liniową funkcję zmiennej x1 oraz błędu losowego (eps)

gen y = 0.5*x1 + eps
hist y	
	
/* aby znaleźć odpowiednie funkcje tworzące np. zmienne losowe - możesz skorzystać z Expression Builder (aby poznać polecenie)
np. Data -> Create or change data -> Create new variable -> Create */ 

/* Nazywanie zmiennych:
- case sensitive
- nazwa może zawierać do 32 znaków spośród 26 liter, 10 cyfr i '_'
- pewne nazwy są zastrzeżone (np.: array, default, global, local, export, new, end)
- http://www.stata.com/manuals13/m-2reswords.pdf
*/

// Ctrl-8 otwiera okno z danymi 

regress y x1 // prosta regresja liniowa; składnia: polecenie zmienna objaśniana [zmienne objaśniające] [inne opcje]

* reg y x1 // to samo co powyżej z wykorzystaniem skrótu polecenia
help regress // wywołuje podstawowe informacje o poleceniu

ereturn list // podaje listę obiektów stworzonych przez ostatnie polecenie

// Np. Wyświetlmy macierz wariancji kowariancji 

matrix define VC = e(V) // zapisujemy macierz kowariancji jako nową macierz VC
matrix list VC // macierz jest symetryczna - pokrywające się komórki nie są wyświetlane ... 

// Zwykle można utworzyć dodatkowe obiekty, np. przewidzieć (polecenie predict) reszty (opcja residuals) i nazwać je reszty0:
predict reszty0, residuals 
// I skorzystać z różnych narzędzi do wizualizacji danych / wyników, np. oberzeć histogram reszt:
histogram reszty0, normal bin(15) // Wygląda jak rozkład normalny (bo tak też wygenerowaliśmy te dane)


// WCZYTYWANIE DANYCH 

clear
// destring lhrwage, dpcomma replace // po wklejeniu zmiennych z excela 
cd "C:\Users\budzi\Documents\ME2024\ME1" // Zmienia aktywnego katalogu - ustawmy na katalog, w którym zapisaliśmy dane i prawo zapisu nowych plików (np. kodu)

* import delimited "me.sleep.txt", delimiter("") // wczytuje surowe dane w formacie .txt nadając im generyczne nazwy; może nie działać w starych wersjach Staty

clear
import delimited "me_sleep.csv", delimiter(";") // w tym pliku dane są zapisane wraz z nazwami zmiennych (w pierwszym wierszu); może nie działać w starych wersjach Staty
* insheet using "C:\Users\mczajkowski\Documents\ME\me.sleep.csv", delimiter(";") // komenda importująca z formatu .csv dla starych wersji Staty

clear
import excel "me_sleep.xlsx", firstrow // może nie działać w starych wersjach Staty

describe // przedstawia opis zmiennych

// dodajmy lepsze etykiety dla zmiennych (na podstawie me.sleep.description.txt

// dodajmy lepsze etykiety dla zmiennych (na podstawie me.sleep.description.txt

label variable age                      "in years"
label variable black                    "=1 if black"
label variable case                     "identifier"
label variable clerical                 "=1 if clerical worker"
label variable construc                 "=1 if construction worker"
label variable educ                     "years of schooling"
label variable earns74                  "total earnings, 1974"
label variable gdhlth                   "=1 if in good or excellent health"
label variable inlf                     "=1 if in labor force"
label variable leis1                    "sleep - totwrk"
label variable leis2                    "slpnaps - totwrk"
label variable leis3                    "rlxall - totwrk"
label variable smsa                     "= 1 if live in smsa"
label variable lhrwage                  "log hourly wage"
label variable lothinc                  "log othinc, unless othinc < 0"
label variable male                     "= 1 if male"
label variable marr                     "= 1 if married"
label variable prot                     "= 1 if Protestant"
label variable rlxall                   "slpnaps + personal activs"
label variable selfe                    "=1 if self employed"
label variable sleep                    "mins sleep at night, per week"
label variable slpnaps                  "mins sleep, including naps, per week"
label variable south                    "=1 if live in south"
label variable spsepay                  "spousal wage income"
label variable spwrk75                  "=1 if spouse works"
label variable totwrk                   "mins worked per week"
label variable union                    "=1 if belong to union"
label variable worknrm                  "mins work main job"
label variable workscnd                 "mins work second job"
label variable exper                    "age - educ - 6"
label variable yngkid                   "=1 if children < 3 present"
label variable yrsmarr                  "years married"
label variable hrwage                   "hourly wage"
label variable agesq                    "age^2"

describe

save me_sleep.dta, replace // zapisujemy zbiór w postaci .dta

use me_sleep.dta, clear // wczytujemy zbiór ponownie czyszcząc to co jest w pamięci, nasze etykiety są zachowane

summarize // podsumowanie zbioru danych

misstable summarize // podsumowanie braków obserwacji w danych

hist hrwage 


replace lhrwage = . if lhrwage == -999 // używamy komendy warunkowej, żeby zamienić '-999' na '.'; zwróć uwagę na '==' oznaczający logiczny test równości, w odróżnieniu od '=' oznaczającego przypisanie
replace hrwage = . if hrwage == -999 

summarize 
misstable summarize
save me_sleep.dta, replace // dane gotowe do analizy

// ZADANIE 2. Korzystając z danych me.sleep.dta sprawdź czy istnieje trade-off między ilością snu, a czasem pracy

clear all // dodatkowo wyrzuca z pamięci skalary, makra, macierze itd.
cls // może nie działać dla starych wersji Staty

log using me1 // Zapisywanie dziennika z wynikami analizy
use me_sleep.dta

// najprostsza z regresji
regress sleep totwrk

// ZADANIE
	// Przekształć zmienne sleep i totwrk tak, żeby były wyrażone w godzinach na dzień 
	// Nazwijmy je sleep2 i totwrk2 
	

regress sleep2 totwrk2

// czy wynik się zmienia jeśli kontroluje się wpływ innych obserwowanych cech respondentów?
generate educ2 = educ^2 // wykorzystamy w modelu nie tylko liczbę lat edukacji, lecz także jej kwadrat, żeby uwzględnić ewentualną nieliniowość jej wpływu
regress sleep2 totwrk2 age agesq male marr educ educ2 lhrwage

// zamiast powtarzać te same zmienne w każdym modelu możemy zdefiniować ich listę, tzw. globalne makro
global xlist age agesq male marr educ educ2 lhrwage
regress sleep2 totwrk2  $xlist

// Czy zmienne socjodemograficzne wpłynęły na wynik? 

drop if missing(lhrwage) // Powinniśmy porównywać z modelem oszacowanym na tej samej próbie
* keep if lhrwage < . // alternative

regress sleep2 totwrk2
regress sleep2 totwrk2  $xlist

log close